@@ -11,13 +11,6 @@ ERROR_INFO = {
 }
 
 
-try:
-    TEXT = unicode
-    UNICODE = unicode
-except NameError:
-    TEXT = str
-    UNICODE = str
-
 def clean_language_name(language):
     if language is None:
         return LANGUAGE
@@ -52,19 +45,20 @@ class BizErrorBase(RuntimeError):
     """
 
     def __init__(self, message=None, code=None, **kwargs):
-        if isinstance(message, self.__class__):
+        if isinstance(message, BizErrorBase):
             code = code or message.code
             message = message.message
         else:
+            # load default code & message
             info = get_error_info(self.__class__.__name__)
             code = code or info["code"]
             message = message or info["message"]
-        # message format
-        if not isinstance(message, TEXT):
-            message = TEXT(str(message), encoding="utf-8")
+            # message format
+            if not isinstance(message, str):
+                message = str(message)
         if kwargs:
             message = message.format(**kwargs)
-        super(BizErrorBase, self).__init__(code, message)
+        super().__init__(code, message)
 
     def __repr__(self):
         return str(self)
@@ -74,11 +68,7 @@ class BizErrorBase(RuntimeError):
             "code": self.args[0],
             "message": self.args[1]
         }, ensure_ascii=False)
-        if TEXT == str:
-            return result
-        else:
-            result = result.encode("utf-8")
-            return result
+        return result
 
     @property
     def code(self):
