@@ -3,7 +3,7 @@ from __future__ import unicode_literals, absolute_import
 from bizerror.base import BizErrorBase
 from bizerror.base import set_error_info
 
-# Created: 2020-10-15 10:42:22.513600
+# Created: 2021-02-19 14:12:15.556000
 # WARNING! All changes made in this file will be lost!
 
 
@@ -30,22 +30,22 @@ set_error_info("zh-hans", "UndefinedError", 1001000001, "未定义的异常")
 class DatabaseError(SysError):
     pass
 set_error_info("en", "DatabaseError", 1001000002, "System Error")
-set_error_info("zh-hans", "DatabaseError", 1001000002, "服务器异常")
+set_error_info("zh-hans", "DatabaseError", 1001000002, "数据库异常")
 
 class CacheError(SysError):
     pass
 set_error_info("en", "CacheError", 1001000003, "System Error")
-set_error_info("zh-hans", "CacheError", 1001000003, "服务器异常")
+set_error_info("zh-hans", "CacheError", 1001000003, "缓存异常")
 
 class MessageQueueError(SysError):
     pass
 set_error_info("en", "MessageQueueError", 1001000004, "System Error")
-set_error_info("zh-hans", "MessageQueueError", 1001000004, "服务器异常")
+set_error_info("zh-hans", "MessageQueueError", 1001000004, "消息队列异常")
 
 class AnotherServiceError(SysError):
     pass
 set_error_info("en", "AnotherServiceError", 1001000005, "System Error")
-set_error_info("zh-hans", "AnotherServiceError", 1001000005, "服务器异常")
+set_error_info("zh-hans", "AnotherServiceError", 1001000005, "外部服务异常")
 
 class HttpError(BizErrorBase):
     pass
@@ -207,6 +207,16 @@ class BadParameterType(ParamError):
 set_error_info("en", "BadParameterType", 1001060003, "Bad parameter type: {parameter}.")
 set_error_info("zh-hans", "BadParameterType", 1001060003, "参数类型有误：{parameter}。")
 
+class StringTooShort(ParamError):
+    pass
+set_error_info("en", "StringTooShort", 1001060004, "String shorter than {min_length}.")
+set_error_info("zh-hans", "StringTooShort", 1001060004, "参数字符数不足，最低要求为：{min_length}。")
+
+class StringTooLong(ParamError):
+    pass
+set_error_info("en", "StringTooLong", 1001060005, "String longer than {max_length}.")
+set_error_info("zh-hans", "StringTooLong", 1001060005, "参数字符数过多，最高限定为：{max_length}。")
+
 class FormError(BizErrorBase):
     pass
 set_error_info("en", "FormError", 1001070000, "Form error.")
